==> bootstrap-reboot-0.1.0.tgz: package/README.md <==
Instruction
----

Normalization of HTML elements, manually forked from [bootstrap _reboot.scss](https://github.com/twbs/bootstrap/blob/v4-dev/scss/_reboot.scss)

Installation
----

  npm install bootstrap-reboot --save



Files
----

+ [bootstrap-reboot.scss](https://github.com/chenzhiguang/bootstrap-reboot/blob/master/bootstrap-reboot.scss)
+ [_variables.scss](https://github.com/chenzhiguang/bootstrap-reboot/blob/master/_variables.scss)
+ [_mixins.scss](https://github.com/chenzhiguang/bootstrap-reboot/blob/master/_mixins.scss)
+ [_reboot.scss](https://github.com/chenzhiguang/bootstrap-reboot/blob/master/_reboot.scss)



Variables and default values
---

+    $font-family-base          : -apple-system, BlinkMacSystemFont, "Segoe UI", Roboto, "Helvetica Neue", Arial, sans-serif, "Apple Color Emoji", "Segoe UI Emoji", "Segoe UI Symbol" !default;
+    $body-color                : #212529 !default;
+    $body-bg                   : #FFF !default;

+    $line-height-base          : 1.5 !default;
+    $font-size-base            : 1rem !default; // Assumes the browser default, typically `16px`
+    $text-muted                : #868e96 !default;
+    $font-weight-base          : normal !default;
+    $paragraph-margin-bottom   : 1rem !default;

+    $link-color                : #007bff !default;
+    $link-hover-color          : darken( #007bff, 15% ) !default;
+    $link-decoration           : none !default;
+    $link-hover-decoration     : underline !default;
+    $enable-hover-media-query  : false !default;

+    $dt-font-weight            : bold !default;
+    $table-cell-padding        : .75rem !default;

==> bootstrap-reboot-0.1.1.tgz: package/README.md <==
Instruction
----

Normalization of HTML elements, manually forked from [bootstrap _reboot.scss](https://github.com/twbs/bootstrap/blob/v4-dev/scss/_reboot.scss)

Installation
----

  npm install bootstrap-reboot --save



Files
----

+ [bootstrap-reboot.scss](https://github.com/chenzhiguang/bootstrap-reboot/blob/master/bootstrap-reboot.scss)
+ [_variables.scss](https://github.com/chenzhiguang/bootstrap-reboot/blob/master/_variables.scss)
+ [_mixins.scss](https://github.com/chenzhiguang/bootstrap-reboot/blob/master/_mixins.scss)
+ [_reboot.scss](https://github.com/chenzhiguang/bootstrap-reboot/blob/master/_reboot.scss)



Variables and default values
---

+    $font-family-base          : -apple-system, BlinkMacSystemFont, "Segoe UI", Roboto, "Helvetica Neue", Arial, sans-serif, "Apple Color Emoji", "Segoe UI Emoji", "Segoe UI Symbol" !default;
+    $body-color                : #212529 !default;
+    $body-bg                   : #FFF !default;

+    $line-height-base          : 1.5 !default;
+    $font-size-base            : 1rem !default; // Assumes the browser default, typically `16px`
+    $text-muted                : #868e96 !default;
+    $font-weight-base          : normal !default;
+    $paragraph-margin-bottom   : 1rem !default;

+    $link-color                : #007bff !default;
+    $link-hover-color          : darken( $link-color, 15% ) !default;
+    $link-decoration           : none !default;
+    $link-hover-decoration     : underline !default;
+    $enable-hover-media-query  : false !default;

+    $dt-font-weight            : bold !default;
+    $table-cell-padding        : .75rem !default;
